@@ -43,6 +43,12 @@ class ISession(ABC):
         """Get configuration."""
         pass
 
+    @property
+    @abstractmethod
+    def storage(self) -> Any:
+        """Get storage manager."""
+        pass
+
     @property
     @abstractmethod
     def read(self) -> IDataFrameReader:
