@@ -64,7 +64,9 @@ class MockPivotGroupedData:
 
             # For each pivot value, filter rows and apply aggregation
             for pivot_value in self.pivot_values:
-                pivot_rows = [row for row in group_rows if row.get(self.pivot_col) == pivot_value]
+                pivot_rows = [
+                    row for row in group_rows if row.get(self.pivot_col) == pivot_value
+                ]
 
                 for expr in exprs:
                     if isinstance(expr, str):
@@ -126,21 +128,33 @@ class MockPivotGroupedData:
         """Evaluate string aggregation expression (reused from MockGroupedData)."""
         if expr.startswith("sum("):
             col_name = expr[4:-1]
-            values = [row.get(col_name, 0) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name, 0)
+                for row in group_rows
+                if row.get(col_name) is not None
+            ]
             return expr, sum(values) if values else 0
         elif expr.startswith("avg("):
             col_name = expr[4:-1]
-            values = [row.get(col_name, 0) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name, 0)
+                for row in group_rows
+                if row.get(col_name) is not None
+            ]
             return expr, sum(values) / len(values) if values else 0
         elif expr.startswith("count("):
             return expr, len(group_rows)
         elif expr.startswith("max("):
             col_name = expr[4:-1]
-            values = [row.get(col_name) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name) for row in group_rows if row.get(col_name) is not None
+            ]
             return expr, max(values) if values else None
         elif expr.startswith("min("):
             col_name = expr[4:-1]
-            values = [row.get(col_name) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name) for row in group_rows if row.get(col_name) is not None
+            ]
             return expr, min(values) if values else None
         else:
             return expr, None
@@ -150,18 +164,28 @@ class MockPivotGroupedData:
     ) -> Tuple[str, Any]:
         """Evaluate MockAggregateFunction (reused from MockGroupedData)."""
         func_name = expr.function_name
-        col_name = getattr(expr, "column_name", "") if hasattr(expr, "column_name") else ""
+        col_name = (
+            getattr(expr, "column_name", "") if hasattr(expr, "column_name") else ""
+        )
 
         # Check if the function has an alias set
         has_alias = expr.name != expr._generate_name()
         alias_name = expr.name if has_alias else None
 
         if func_name == "sum":
-            values = [row.get(col_name, 0) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name, 0)
+                for row in group_rows
+                if row.get(col_name) is not None
+            ]
             result_key = alias_name if alias_name else f"sum({col_name})"
             return result_key, sum(values) if values else 0
         elif func_name == "avg":
-            values = [row.get(col_name, 0) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name, 0)
+                for row in group_rows
+                if row.get(col_name) is not None
+            ]
             result_key = alias_name if alias_name else f"avg({col_name})"
             return result_key, sum(values) / len(values) if values else 0
         elif func_name == "count":
@@ -172,11 +196,15 @@ class MockPivotGroupedData:
                 result_key = alias_name if alias_name else f"count({col_name})"
                 return result_key, len(group_rows)
         elif func_name == "max":
-            values = [row.get(col_name) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name) for row in group_rows if row.get(col_name) is not None
+            ]
             result_key = alias_name if alias_name else f"max({col_name})"
             return result_key, max(values) if values else None
         elif func_name == "min":
-            values = [row.get(col_name) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name) for row in group_rows if row.get(col_name) is not None
+            ]
             result_key = alias_name if alias_name else f"min({col_name})"
             return result_key, min(values) if values else None
         else:
@@ -192,21 +220,33 @@ class MockPivotGroupedData:
         expr_name = expr.name
         if expr_name.startswith("sum("):
             col_name = expr_name[4:-1]
-            values = [row.get(col_name, 0) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name, 0)
+                for row in group_rows
+                if row.get(col_name) is not None
+            ]
             return expr_name, sum(values) if values else 0
         elif expr_name.startswith("avg("):
             col_name = expr_name[4:-1]
-            values = [row.get(col_name, 0) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name, 0)
+                for row in group_rows
+                if row.get(col_name) is not None
+            ]
             return expr_name, sum(values) / len(values) if values else 0
         elif expr_name.startswith("count("):
             return expr_name, len(group_rows)
         elif expr_name.startswith("max("):
             col_name = expr_name[4:-1]
-            values = [row.get(col_name) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name) for row in group_rows if row.get(col_name) is not None
+            ]
             return expr_name, max(values) if values else None
         elif expr_name.startswith("min("):
             col_name = expr_name[4:-1]
-            values = [row.get(col_name) for row in group_rows if row.get(col_name) is not None]
+            values = [
+                row.get(col_name) for row in group_rows if row.get(col_name) is not None
+            ]
             return expr_name, min(values) if values else None
         else:
             return expr_name, None
