@@ -50,6 +50,9 @@ class MockRollupGroupedData(MockGroupedData):
 
         result_data = []
 
+        # Track which result keys are from count/rank functions (non-nullable)
+        non_nullable_keys = set()
+
         # Generate rollup combinations: for each level i, group by first i columns
         for i in range(len(self.rollup_columns) + 1):
             if i == 0:
@@ -63,6 +66,9 @@ class MockRollupGroupedData(MockGroupedData):
                         result_key, result_value = self._evaluate_string_expression(
                             expr, filtered_rows
                         )
+                        # Check if this is a count function
+                        if expr.startswith("count("):
+                            non_nullable_keys.add(result_key)
                         result_row[result_key] = result_value
                     elif hasattr(expr, "function_name"):
                         from typing import cast
@@ -71,6 +77,9 @@ class MockRollupGroupedData(MockGroupedData):
                         result_key, result_value = self._evaluate_aggregate_function(
                             cast(MockAggregateFunction, expr), filtered_rows
                         )
+                        # Check if this is a count function
+                        if expr.function_name == "count":
+                            non_nullable_keys.add(result_key)
                         result_row[result_key] = result_value
                     elif hasattr(expr, "name"):
                         result_key, result_value = self._evaluate_column_expression(
@@ -108,14 +117,22 @@ class MockRollupGroupedData(MockGroupedData):
                             result_key, result_value = self._evaluate_string_expression(
                                 expr, group_rows
                             )
+                            # Check if this is a count function
+                            if expr.startswith("count("):
+                                non_nullable_keys.add(result_key)
                             result_row[result_key] = result_value
                         elif hasattr(expr, "function_name"):
                             from typing import cast
                             from ...functions import MockAggregateFunction
 
-                            result_key, result_value = self._evaluate_aggregate_function(
-                                cast(MockAggregateFunction, expr), group_rows
+                            result_key, result_value = (
+                                self._evaluate_aggregate_function(
+                                    cast(MockAggregateFunction, expr), group_rows
+                                )
                             )
+                            # Check if this is a count function
+                            if expr.function_name == "count":
+                                non_nullable_keys.add(result_key)
                             result_row[result_key] = result_value
                         elif hasattr(expr, "name"):
                             result_key, result_value = self._evaluate_column_expression(
@@ -142,12 +159,49 @@ class MockRollupGroupedData(MockGroupedData):
         for key, value in result_data[0].items():
             if key in self.rollup_columns:
                 fields.append(MockStructField(key, StringType()))
-            elif isinstance(value, int):
-                fields.append(MockStructField(key, LongType()))
-            elif isinstance(value, float):
-                fields.append(MockStructField(key, DoubleType()))
             else:
-                # Fallback for any other type
-                fields.append(MockStructField(key, StringType()))
+                # Count functions, window ranking functions, and boolean functions are non-nullable in PySpark
+                is_count_function = key in non_nullable_keys or any(
+                    key.startswith(func)
+                    for func in [
+                        "count(",
+                        "count(1)",
+                        "count(DISTINCT",
+                        "count_if",
+                        "row_number",
+                        "rank",
+                        "dense_rank",
+                        "row_num",
+                        "dept_row_num",
+                        "global_row",
+                        "dept_row",
+                        "dept_rank",
+                    ]
+                )
+                is_boolean_function = any(
+                    key.startswith(func)
+                    for func in ["coalesced_", "is_null_", "is_nan_"]
+                )
+                nullable = not (is_count_function or is_boolean_function)
+
+                if isinstance(value, int):
+                    fields.append(
+                        MockStructField(
+                            key, LongType(nullable=nullable), nullable=nullable
+                        )
+                    )
+                elif isinstance(value, float):
+                    fields.append(
+                        MockStructField(
+                            key, DoubleType(nullable=nullable), nullable=nullable
+                        )
+                    )
+                else:
+                    # Fallback for any other type
+                    fields.append(
+                        MockStructField(
+                            key, StringType(nullable=nullable), nullable=nullable
+                        )
+                    )
         schema = MockStructType(fields)
         return MockDataFrame(result_data, schema)
