@@ -6,6 +6,7 @@ for MockDataFrame. Extracted from dataframe.py to improve organization.
 """
 
 from typing import Any, List, TYPE_CHECKING
+from ..spark_types import StringType, MockStructField, DoubleType, LongType, IntegerType, BooleanType, MockDataType, MockStructType, ArrayType
 
 if TYPE_CHECKING:
     from mock_spark.dataframe import MockDataFrame
@@ -16,7 +17,9 @@ class LazyEvaluationEngine:
     """Handles lazy evaluation and materialization for DataFrames."""
 
     @staticmethod
-    def queue_operation(df: "MockDataFrame", op_name: str, payload: Any) -> "MockDataFrame":
+    def queue_operation(
+        df: "MockDataFrame", op_name: str, payload: Any
+    ) -> "MockDataFrame":
         """Queue an operation for lazy evaluation.
 
         Args:
@@ -66,15 +69,24 @@ class LazyEvaluationEngine:
             materializer = BackendFactory.create_materializer("duckdb")
             try:
                 # Let materializer optimize and execute the operations
-                rows = materializer.materialize(df.data, df.schema, df._operations_queue)
+                rows = materializer.materialize(
+                    df.data, df.schema, df._operations_queue
+                )
 
                 # Convert rows back to data format
-                materialized_data = LazyEvaluationEngine._convert_materialized_rows(rows, df.schema)
+                materialized_data = LazyEvaluationEngine._convert_materialized_rows(
+                    rows, df.schema
+                )
 
                 # Create new eager DataFrame with materialized data
                 from ..dataframe import MockDataFrame
 
-                return MockDataFrame(materialized_data, df.schema, df.storage, is_lazy=False)  # type: ignore[has-type]
+                return MockDataFrame(
+                    materialized_data,
+                    df.schema,
+                    df.storage,  # type: ignore[has-type]
+                    is_lazy=False,
+                )
             finally:
                 materializer.close()
 
@@ -83,7 +95,9 @@ class LazyEvaluationEngine:
             return LazyEvaluationEngine._materialize_manual(df)
 
     @staticmethod
-    def _convert_materialized_rows(rows: List[Any], schema: "MockStructType") -> List[dict]:
+    def _convert_materialized_rows(
+        rows: List[Any], schema: "MockStructType"
+    ) -> List[dict]:
         """Convert materialized rows to proper data format with type conversion.
 
         Args:
@@ -93,7 +107,7 @@ class LazyEvaluationEngine:
         Returns:
             List of dictionaries with proper types
         """
-        from ..spark_types import ArrayType, IntegerType, LongType, DoubleType
+        from ..spark_types import ArrayType
 
         materialized_data = []
         for row in rows:
@@ -138,6 +152,12 @@ class LazyEvaluationEngine:
                             row_dict[field.name] = float(value)
                         except (ValueError, TypeError):
                             pass  # Keep as string if conversion fails
+                    else:
+                        # Convert Decimal or other numeric types to float
+                        try:
+                            row_dict[field.name] = float(value)
+                        except (ValueError, TypeError):
+                            pass  # Keep original value if conversion fails
 
             materialized_data.append(row_dict)
 
@@ -201,15 +221,7 @@ class LazyEvaluationEngine:
         Returns:
             Inferred schema for selected columns
         """
-        from ..spark_types import (
-            StringType,
-            LongType,
-            DoubleType,
-            IntegerType,
-            MockStructField,
-            MockStructType,
-            ArrayType,
-        )
+        from ..functions import MockAggregateFunction
 
         new_fields = []
         for col in columns:
@@ -255,31 +267,164 @@ class LazyEvaluationEngine:
                     new_fields.append(MockStructField(col_name, IntegerType()))
                 elif col.operation == "split":
                     # Split returns ArrayType of strings
-                    new_fields.append(MockStructField(col_name, ArrayType(StringType())))
+                    new_fields.append(
+                        MockStructField(col_name, ArrayType(StringType()))
+                    )
+                elif col.operation in ["isnull", "isnotnull", "isnan"]:
+                    # Boolean operations - always return BooleanType and are non-nullable
+
+                    new_fields.append(
+                        MockStructField(col_name, BooleanType(), nullable=False)
+                    )
+                elif col.operation == "coalesce":
+                    # Coalesce with a non-null literal fallback is non-nullable
+                    # Determine the result type from the first argument
+                    source_type: Any = StringType()
+                    if hasattr(col, "column") and hasattr(col.column, "name"):
+                        # Find source column type
+                        for field in df.schema.fields:
+                            if field.name == col.column.name:
+                                source_type = field.dataType
+                                break
+                    # Mark as non-nullable if there's a literal fallback
+                    new_fields.append(
+                        MockStructField(col_name, source_type, nullable=False)
+                    )
                 else:
                     # Default to StringType for unknown operations
                     new_fields.append(MockStructField(col_name, StringType()))
-            elif hasattr(col, "conditions") and hasattr(col, "default_value"):
-                # Handle MockCaseWhen objects
+            elif isinstance(col, MockAggregateFunction):
+                # Handle aggregate functions - set proper nullability
                 col_name = col.name
-                # CASE WHEN can return various types - infer from default value
-                if hasattr(col.default_value, "name"):
-                    # Default is a column reference - try to find its type
-                    found = False
-                    for field in df.schema.fields:
-                        if field.name == col.default_value.name:
-                            new_fields.append(MockStructField(col_name, field.dataType))
-                            found = True
-                            break
-                    if not found:
-                        new_fields.append(MockStructField(col_name, IntegerType()))
-                elif isinstance(col.default_value, int):
-                    new_fields.append(MockStructField(col_name, IntegerType()))
-                elif isinstance(col.default_value, float):
-                    new_fields.append(MockStructField(col_name, DoubleType()))
+
+                # Determine nullable based on function type
+                non_nullable_functions = {
+                    "count",
+                    "countDistinct",
+                    "count_if",
+                    "row_number",
+                    "rank",
+                    "dense_rank",
+                }
+
+                nullable = col.function_name not in non_nullable_functions
+
+                # Use provided data type or default to LongType for counts, DoubleType otherwise
+                if col.data_type:
+                    data_type = col.data_type
+                    if hasattr(data_type, "nullable"):
+                        data_type.nullable = nullable
+                elif col.function_name in {"count", "countDistinct", "count_if"}:
+                    data_type = LongType(nullable=nullable)
                 else:
-                    # Default to IntegerType for CASE WHEN
+                    data_type = DoubleType(nullable=nullable)
+
+                new_fields.append(
+                    MockStructField(col_name, data_type, nullable=nullable)
+                )
+
+            elif hasattr(col, "function_name") and hasattr(col, "window_spec"):
+                # Handle MockWindowFunction (e.g., rank().over(window))
+                col_name = col.name
+
+                # Window functions that are non-nullable
+                non_nullable_window_functions = {
+                    "row_number",
+                    "rank",
+                    "dense_rank",
+                }
+
+                # Determine type and nullability based on function
+                if col.function_name in non_nullable_window_functions:
+                    # Ranking functions return IntegerType and are non-nullable
+                    new_fields.append(
+                        MockStructField(col_name, IntegerType(), nullable=False)
+                    )
+                elif col.function_name in ["lag", "lead"]:
+                    # Lag/lead can return null (out of bounds)
+                    if col.column_name:
+                        # Find source column type
+                        source_type2: Any = StringType()
+                        for field in df.schema.fields:
+                            if field.name == col.column_name:
+                                source_type2 = field.dataType
+                                break
+                        new_fields.append(
+                            MockStructField(col_name, source_type2, nullable=True)
+                        )
+                    else:
+                        new_fields.append(
+                            MockStructField(col_name, StringType(), nullable=True)
+                        )
+                elif col.function_name in ["sum", "avg", "min", "max"]:
+                    # Aggregate window functions - nullable
+                    new_fields.append(
+                        MockStructField(col_name, DoubleType(), nullable=True)
+                    )
+                elif col.function_name in ["count", "countDistinct"]:
+                    # Count functions are non-nullable
+                    new_fields.append(
+                        MockStructField(col_name, LongType(), nullable=False)
+                    )
+                else:
+                    # Default for other window functions
+                    new_fields.append(
+                        MockStructField(col_name, DoubleType(), nullable=True)
+                    )
+
+            elif hasattr(col, "value") and hasattr(col, "data_type"):
+                # Handle MockLiteral objects - literals are never nullable
+                col_name = col.name
+                # Use the literal's data_type and explicitly set nullable=False
+
+                data_type = col.data_type
+                # Create a new instance of the data type with nullable=False
+                data_type_non_null: MockDataType
+                if isinstance(data_type, BooleanType):
+                    data_type_non_null = BooleanType(nullable=False)
+                elif isinstance(data_type, IntegerType):
+                    data_type_non_null = IntegerType(nullable=False)
+                elif isinstance(data_type, LongType):
+                    data_type_non_null = LongType(nullable=False)
+                elif isinstance(data_type, DoubleType):
+                    data_type_non_null = DoubleType(nullable=False)
+                elif isinstance(data_type, StringType):
+                    data_type_non_null = StringType(nullable=False)
+                else:
+                    # For other types, create a new instance with nullable=False
+                    data_type_non_null = data_type.__class__(nullable=False)
+
+                new_fields.append(
+                    MockStructField(col_name, data_type_non_null, nullable=False)
+                )
+            elif hasattr(col, "conditions") and hasattr(col, "default_value"):
+                # Handle MockCaseWhen objects - use get_result_type() method
+                col_name = col.name
+                from ..functions.conditional import MockCaseWhen
+
+                if isinstance(col, MockCaseWhen):
+                    # Use the proper type inference method
+                    inferred_type = col.get_result_type()
+                    new_fields.append(
+                        MockStructField(col_name, inferred_type, nullable=False)
+                    )
+                else:
+                    # Fallback for other conditional objects
                     new_fields.append(MockStructField(col_name, IntegerType()))
+            elif hasattr(col, "conditions"):
+                # Handle MockCaseWhen objects that didn't match the first condition
+                col_name = col.name
+                from ..functions.conditional import MockCaseWhen
+
+                if isinstance(col, MockCaseWhen):
+                    # Use the proper type inference method
+                    inferred_type = col.get_result_type()
+                    new_fields.append(
+                        MockStructField(col_name, inferred_type, nullable=False)
+                    )
+                else:
+                    # Default to StringType for unknown operations
+                    new_fields.append(MockStructField(col_name, StringType()))
             elif hasattr(col, "name"):
                 # Handle MockColumn
                 col_name = col.name
@@ -342,7 +487,9 @@ class LazyEvaluationEngine:
         original_columns = {field.name for field in original_schema.fields}
 
         # Check if the filter references any of the original columns
-        if hasattr(filter_condition, "column") and hasattr(filter_condition.column, "name"):
+        if hasattr(filter_condition, "column") and hasattr(
+            filter_condition.column, "name"
+        ):
             column_name = filter_condition.column.name
             return column_name in original_columns
         elif hasattr(filter_condition, "name"):
