@@ -11,12 +11,25 @@ from mock_spark.spark_types import MockDataType, StringType
 # Import core classes from their canonical locations
 from .core.column import MockColumn, MockColumnOperation
 from .core.literals import MockLiteral
+from .core.lambda_parser import (
+    MockLambdaExpression,
+    LambdaParser,
+    LambdaTranslationError,
+)
 
 if TYPE_CHECKING:
     from .window_execution import MockWindowFunction
 
 # Re-export for backward compatibility
-__all__ = ["MockColumn", "MockColumnOperation", "MockLiteral", "MockAggregateFunction"]
+__all__ = [
+    "MockColumn",
+    "MockColumnOperation",
+    "MockLiteral",
+    "MockAggregateFunction",
+    "MockLambdaExpression",
+    "LambdaParser",
+    "LambdaTranslationError",
+]
 
 
 class MockAggregateFunction:
@@ -41,8 +54,32 @@ class MockAggregateFunction:
         """
         self.column = column
         self.function_name = function_name
-        self.data_type = data_type or StringType()
+        self.data_type = self._configure_data_type(data_type)
         self.name = self._generate_name()
+        # Optional attributes for specific functions
+        self.ord_column: Optional[Union[MockColumn, str]] = None  # For max_by, min_by
+
+    def _configure_data_type(self, data_type: Optional[MockDataType]) -> MockDataType:
+        """Configure data type with appropriate nullability based on function type."""
+        if not data_type:
+            return StringType()
+
+        # Functions that always return non-nullable results in PySpark
+        non_nullable_functions = {
+            "count",
+            "countDistinct",
+            "row_number",
+            "rank",
+            "dense_rank",
+            "isNull",
+            "isnan",
+            "coalesce",
+        }
+
+        if self.function_name in non_nullable_functions:
+            data_type.nullable = False
+
+        return data_type
 
     @property
     def column_name(self) -> str:
@@ -103,7 +140,9 @@ class MockAggregateFunction:
         if self.column is None:
             return len(data)
         else:
-            column_name = self.column if isinstance(self.column, str) else self.column.name
+            column_name = (
+                self.column if isinstance(self.column, str) else self.column.name
+            )
             return sum(1 for row in data if row.get(column_name) is not None)
 
     def _evaluate_sum(self, data: List[dict]) -> Any:
@@ -125,7 +164,9 @@ class MockAggregateFunction:
             return 0.0
 
         column_name = self.column if isinstance(self.column, str) else self.column.name
-        values = [row.get(column_name) for row in data if row.get(column_name) is not None]
+        values = [
+            row.get(column_name) for row in data if row.get(column_name) is not None
+        ]
         numeric_values = [v for v in values if isinstance(v, (int, float))]
         if numeric_values:
             return sum(numeric_values) / len(numeric_values)
@@ -138,7 +179,9 @@ class MockAggregateFunction:
             return None
 
         column_name = self.column if isinstance(self.column, str) else self.column.name
-        values = [row.get(column_name) for row in data if row.get(column_name) is not None]
+        values = [
+            row.get(column_name) for row in data if row.get(column_name) is not None
+        ]
         if values:
             return max(values)  # type: ignore[type-var]
         else:
@@ -150,7 +193,9 @@ class MockAggregateFunction:
             return None
 
         column_name = self.column if isinstance(self.column, str) else self.column.name
-        values = [row.get(column_name) for row in data if row.get(column_name) is not None]
+        values = [
+            row.get(column_name) for row in data if row.get(column_name) is not None
+        ]
         if values:
             return min(values)  # type: ignore[type-var]
         else:
