@@ -4,9 +4,12 @@ Conditional functions for Mock Spark.
 This module contains conditional functions including CASE WHEN expressions.
 """
 
-from typing import Any, List, Union
+from typing import Any, List, Union, TYPE_CHECKING
 from mock_spark.functions.base import MockColumn, MockColumnOperation
 
+if TYPE_CHECKING:
+    from mock_spark.spark_types import MockDataType
+
 
 class MockCaseWhen:
     """Represents a CASE WHEN expression.
@@ -96,6 +99,68 @@ class MockCaseWhen:
         # Return default value if no condition matches
         return self._evaluate_value(row, self.default_value)
 
+    def get_result_type(self) -> "MockDataType":
+        """Infer the result type from condition values."""
+        from ..spark_types import BooleanType, IntegerType, StringType, DoubleType
+        from .core.literals import MockLiteral
+
+        # Check all condition values and default value
+        all_values = [v for _, v in self.conditions]
+        if self.default_value is not None:
+            all_values.append(self.default_value)
+
+        # Check if all values are literals (which are never nullable)
+        all_literals = all(
+            isinstance(val, MockLiteral) or val is None for val in all_values
+        )
+
+        for val in all_values:
+            if val is not None:
+                if isinstance(val, MockLiteral):
+                    # For MockLiteral, create a new instance with correct nullable
+                    data_type = val.data_type
+                    if isinstance(data_type, BooleanType):
+                        return BooleanType(
+                            nullable=False
+                        )  # Literals are never nullable
+                    elif isinstance(data_type, IntegerType):
+                        return IntegerType(
+                            nullable=False
+                        )  # Literals are never nullable
+                    elif isinstance(data_type, DoubleType):
+                        return DoubleType(nullable=False)  # Literals are never nullable
+                    elif isinstance(data_type, StringType):
+                        return StringType(nullable=False)  # Literals are never nullable
+                    else:
+                        # For other types, create with correct nullable
+                        return data_type.__class__(
+                            nullable=False
+                        )  # Literals are never nullable
+                elif isinstance(val, bool):
+                    return BooleanType(nullable=False)  # Literals are never nullable
+                elif isinstance(val, int):
+                    return IntegerType(nullable=False)  # Literals are never nullable
+                elif isinstance(val, float):
+                    return DoubleType(nullable=False)  # Literals are never nullable
+                elif isinstance(val, str):
+                    return StringType(nullable=False)  # Literals are never nullable
+                elif hasattr(val, "operation") and hasattr(val, "column"):
+                    # Handle MockColumnOperation - check the operation type
+                    from ..spark_types import LongType
+
+                    if val.operation in ["+", "-", "*", "/", "%", "abs"]:
+                        # Arithmetic operations return LongType
+                        return LongType(nullable=False)
+                    elif val.operation in ["round"]:
+                        # Round operations return DoubleType
+                        return DoubleType(nullable=False)
+                    else:
+                        # Default to StringType for other operations
+                        return StringType(nullable=False)
+
+        # Default to LongType for arithmetic operations, not BooleanType
+        return LongType(nullable=not all_literals)
+
     def _evaluate_condition(self, row: dict, condition: Any) -> bool:
         """Evaluate a condition for a given row.
 
@@ -137,26 +202,60 @@ class MockCaseWhen:
         elif operation.operation == ">":
             left_value = self._get_column_value(row, operation.column)
             right_value = self._get_column_value(row, operation.value)
-            return left_value is not None and right_value is not None and left_value > right_value
+            return (
+                left_value is not None
+                and right_value is not None
+                and left_value > right_value
+            )
         elif operation.operation == ">=":
             left_value = self._get_column_value(row, operation.column)
             right_value = self._get_column_value(row, operation.value)
-            return left_value is not None and right_value is not None and left_value >= right_value
+            return (
+                left_value is not None
+                and right_value is not None
+                and left_value >= right_value
+            )
         elif operation.operation == "<":
             left_value = self._get_column_value(row, operation.column)
             right_value = self._get_column_value(row, operation.value)
-            return left_value is not None and right_value is not None and left_value < right_value
+            return (
+                left_value is not None
+                and right_value is not None
+                and left_value < right_value
+            )
         elif operation.operation == "<=":
             left_value = self._get_column_value(row, operation.column)
             right_value = self._get_column_value(row, operation.value)
-            return left_value is not None and right_value is not None and left_value <= right_value
+            return (
+                left_value is not None
+                and right_value is not None
+                and left_value <= right_value
+            )
         elif operation.operation == "&":
-            left_result = self._evaluate_column_operation(row, operation.column)
-            right_result = self._evaluate_column_operation(row, operation.value)
+            # Prevent infinite recursion - check if operands are operations
+            if hasattr(operation.column, "operation"):
+                left_result = self._evaluate_column_operation(row, operation.column)
+            else:
+                left_result = self._evaluate_condition(row, operation.column)
+
+            if hasattr(operation.value, "operation"):
+                right_result = self._evaluate_column_operation(row, operation.value)
+            else:
+                right_result = self._evaluate_condition(row, operation.value)
+
             return left_result and right_result
         elif operation.operation == "|":
-            left_result = self._evaluate_column_operation(row, operation.column)
-            right_result = self._evaluate_column_operation(row, operation.value)
+            # Prevent infinite recursion - check if operands are operations
+            if hasattr(operation.column, "operation"):
+                left_result = self._evaluate_column_operation(row, operation.column)
+            else:
+                left_result = self._evaluate_condition(row, operation.column)
+
+            if hasattr(operation.value, "operation"):
+                right_result = self._evaluate_column_operation(row, operation.value)
+            else:
+                right_result = self._evaluate_condition(row, operation.value)
+
             return left_result or right_result
         else:
             return False
@@ -188,7 +287,12 @@ class MockCaseWhen:
         Returns:
             The evaluated value.
         """
-        if hasattr(value, "operation") and hasattr(value, "column"):
+        from .core.literals import MockLiteral
+
+        if isinstance(value, MockLiteral):
+            # For MockLiteral, return the actual value
+            return value.value
+        elif hasattr(value, "operation") and hasattr(value, "column"):
             # Handle MockColumnOperation (e.g., unary minus, arithmetic operations)
             from mock_spark.functions.base import MockColumnOperation
 
@@ -334,3 +438,64 @@ class ConditionalFunctions:
         if value is not None:
             return MockCaseWhen(condition=condition, value=value)
         return MockCaseWhen(condition=condition)
+
+    @staticmethod
+    def assert_true(
+        condition: Union[MockColumn, MockColumnOperation],
+    ) -> MockColumnOperation:
+        """Assert that a condition is true, raises error if false.
+
+        Args:
+            condition: Boolean condition to assert.
+
+        Returns:
+            MockColumnOperation representing the assert_true function.
+
+        Example:
+            >>> df.select(F.assert_true(F.col("value") > 0))
+        """
+        return MockColumnOperation(
+            condition if isinstance(condition, MockColumn) else condition.column,
+            "assert_true",
+            condition if not isinstance(condition, MockColumn) else None,
+            name=f"assert_true({condition if isinstance(condition, str) else getattr(condition, 'name', 'condition')})",
+        )
+
+    # Priority 2: Conditional/Null Functions
+    @staticmethod
+    def ifnull(
+        col1: Union[MockColumn, str], col2: Union[MockColumn, str]
+    ) -> MockColumnOperation:
+        """Alias for coalesce(col1, col2) - Returns col2 if col1 is null (PySpark 3.5+).
+
+        Args:
+            col1: First column.
+            col2: Second column (replacement for null).
+
+        Returns:
+            MockColumnOperation representing the ifnull function.
+        """
+        return ConditionalFunctions.coalesce(col1, col2)
+
+    @staticmethod
+    def nullif(
+        col1: Union[MockColumn, str], col2: Union[MockColumn, str]
+    ) -> MockColumnOperation:
+        """Returns null if col1 equals col2, otherwise returns col1 (PySpark 3.5+).
+
+        Args:
+            col1: First column.
+            col2: Second column to compare.
+
+        Returns:
+            MockColumnOperation representing the nullif function.
+        """
+        column1 = MockColumn(col1) if isinstance(col1, str) else col1
+        column2 = MockColumn(col2) if isinstance(col2, str) else col2
+
+        return MockColumnOperation(
+            column1,
+            "nullif",
+            value=column2,
+            name=f"nullif({column1.name}, {column2.name})",
+        )
