@@ -240,6 +240,7 @@ class MockColumnOperation(IColumn):
         self.value = value
         self._name = name or self._generate_name()
         self.function_name = operation
+        self.return_type: Optional[Any] = None  # Type hint for return type
 
     @property
     def name(self) -> str:
@@ -311,7 +312,9 @@ class MockColumnOperation(IColumn):
 
     def alias(self, name: str) -> "MockColumnOperation":
         """Create an alias for this operation."""
-        aliased_operation = MockColumnOperation(self.column, self.operation, self.value, name)
+        aliased_operation = MockColumnOperation(
+            self.column, self.operation, self.value, name
+        )
         return aliased_operation
 
     def __eq__(self, other: Any) -> "MockColumnOperation":  # type: ignore[override]
