@@ -36,27 +36,33 @@ def mock_type_to_sqlalchemy(mock_type: Any) -> Any:
     """
     from sqlalchemy import ARRAY, VARCHAR
     from sqlalchemy.types import TypeDecorator
-    
+
     # Get type name
     type_name = type(mock_type).__name__
-    
-    # Handle ArrayType
+
+    # Handle ArrayType with element type
     if "ArrayType" in type_name or "Array" in type_name:
-        return ARRAY(VARCHAR)
-    
+        # Check if the array has an element type specified
+        if hasattr(mock_type, "elementType"):
+            element_sql_type = mock_type_to_sqlalchemy(mock_type.elementType)
+            return ARRAY(element_sql_type)
+        else:
+            # Fallback to VARCHAR for untyped arrays
+            return ARRAY(VARCHAR)
+
     # Handle MapType - use custom type that will be handled with raw SQL
     if "MapType" in type_name or "Map" in type_name:
         # Return a marker type that we can detect later
         class DuckDBMapType(TypeDecorator):
             impl = String
             cache_ok = True
-            
+
             def __init__(self) -> None:
                 super().__init__()
                 self.is_duckdb_map = True  # Marker attribute
-        
+
         return DuckDBMapType
-    
+
     # Type mapping from MockSpark type names to SQLAlchemy types
     type_mapping = {
         "StringType": String,
@@ -278,14 +284,22 @@ class TableFactory:
         """
         self.metadata = metadata or MetaData()
 
-    def from_mock_schema(self, table_name: str, mock_schema: Any, **kwargs: Any) -> Table:
+    def from_mock_schema(
+        self, table_name: str, mock_schema: Any, **kwargs: Any
+    ) -> Table:
         """Create table from MockSpark schema."""
-        return create_table_from_mock_schema(table_name, mock_schema, self.metadata, **kwargs)
+        return create_table_from_mock_schema(
+            table_name, mock_schema, self.metadata, **kwargs
+        )
 
-    def from_data(self, table_name: str, data: List[Dict[str, Any]], **kwargs: Any) -> Table:
+    def from_data(
+        self, table_name: str, data: List[Dict[str, Any]], **kwargs: Any
+    ) -> Table:
         """Create table by inferring types from data."""
         return create_table_from_data(table_name, data, self.metadata, **kwargs)
 
-    def from_columns(self, table_name: str, columns: List[Column], **kwargs: Any) -> Table:
+    def from_columns(
+        self, table_name: str, columns: List[Column], **kwargs: Any
+    ) -> Table:
         """Create table from list of Column objects."""
         return Table(table_name, self.metadata, *columns, **kwargs)
